@@ -1,4 +1,5 @@
 import os
+import sys
 import yaml
 import logging
 import subprocess
@@ -41,7 +42,8 @@ class network3_perseus():
         print("File size according to `FileInfoQuery`: ", info.size)
 
     def push_config(self,yaml_contents):
-        env = Environment(loader=PackageLoader("src/network3_perseus", "src/templates"))
+        print(sys.path)
+        env = Environment(loader=PackageLoader("network3_perseus", "src/templates"))
         autoescape=select_autoescape()
         intended_config_template = env.get_template('intended_config.j2')
         rendered_intended_config = intended_config_template.render(yaml_contents)
